require 'faraday'

module FerrisBueller
  class Client
    attr_reader :connection

    def initialize(options = {})
      @url = from_options(:url, options)
      @token = from_options(:token, options)

      @connection = Faraday.new(url: @url)
      @connection.token_auth(@token)
    end

    def from_options(key, options)
      if value = options[key]
        value
      else
        raise ArgumentError.new "#{key.inspect} is required."
      end
    end

    def create_event(event_attributes)
      validate_event_attributes(event_attributes)
      self.connection.post '/api/events', event_attributes
    end

    def validate_event_attributes(event_attributes)
      event = event_attributes[:event] || event_attributes['event']
      raise ArgumentError.new ":event is required." unless event

      [:title, :venue, :shows, :source_listing, :source].each do |key|
        unless event[key] || event[key.to_s]
          raise ArgumentError.new ":event => #{key.inspect} is required."
        end
      end
    end
  end
end
